import { __decorate } from "tslib";
import { HPCCResizeElement, css, customElement, display, html, ref, attribute, property } from "@hpcc-js/wc-core";
import { compile, ojs2notebook, omd2notebook } from "@hpcc-js/observablehq-compiler";
import { Inspector, Library, Runtime } from "@observablehq/runtime";
const template = html `\
<div ${ref("_div")}>
</div>
<slot ${ref("_slot")}></slot>
`;
const styles = css `
${display("inline-block")}

:host  {
    width:100%;
    overflow-y: auto;
}

:host > slot {
    display: none;
}

:host > div.hide-values .observablehq--inspect {
    display: none;
}

:host > div .observablehq--error > .observablehq--inspect {
    display: none;
}

:host > div.show-errors .observablehq--error > .observablehq--inspect {
    display: block;
}

`;
let HPCCObservableElement = class HPCCObservableElement extends HPCCResizeElement {
    constructor() {
        super();
        /**
         * Default mode, Observable script with embedded Markdown, or Markdown with
         * embedded Observable script
         *
         * @typeParam observablescript - Observable script with embedded Markdown
         * @typeParam markdown - Markdown with embedded Observable script
         *
         * @defaultValue observablescript
         */
        this.mode = "observablescript";
        /**
         * Show or hide intermediate values (values which typically are not `viewof` values)
         *
         * @defaultValue false
         */
        this.show_values = false;
        /**
         * Show or hide errors, enable to assist with non functioning scripts
         *
         * @defaultValue false
         */
        this.show_errors = false;
        /**
         * Plugins expose JavaScript functions to the Observable script
         *
         * @defaultValue \{\}
         */
        this.plugins = {};
        this._content = "";
        this.construct();
        this._slot.addEventListener("slotchange", () => this.construct());
    }
    construct() {
        const text = this._slot.assignedNodes().map(n => n.textContent).join("\n");
        this._content = text;
    }
    enter() {
        super.enter();
    }
    update(changes) {
        super.update(changes);
        this._div?.classList.toggle("hide-values", !this.show_values);
        this._div?.classList.toggle("show-errors", this.show_errors);
        if (changes._content) {
            this._div.innerHTML = "";
            const nb = this.mode === "observablescript" ? ojs2notebook(this._content) : omd2notebook(this._content);
            compile(nb).then(compiledNB => {
                const library = new Library();
                const runtime = new Runtime(library);
                compiledNB(runtime, name => {
                    const div = document.createElement("div");
                    this._div.appendChild(div);
                    return new Inspector(div);
                });
            });
        }
    }
};
__decorate([
    attribute
], HPCCObservableElement.prototype, "mode", void 0);
__decorate([
    attribute({ type: "boolean" })
], HPCCObservableElement.prototype, "show_values", void 0);
__decorate([
    attribute({ type: "boolean" })
], HPCCObservableElement.prototype, "show_errors", void 0);
__decorate([
    property
], HPCCObservableElement.prototype, "plugins", void 0);
__decorate([
    property
], HPCCObservableElement.prototype, "_content", void 0);
HPCCObservableElement = __decorate([
    customElement("hpcc-observable", { template, styles })
], HPCCObservableElement);
export { HPCCObservableElement };
//# sourceMappingURL=observable.js.map